@@ -26,6 +26,8 @@ our @EXPORT = qw{
 
     upload_plugin
 
+    plugin_meta
+
 };
 
 
@@ -331,7 +333,7 @@ sub upload_plugin {
 
     print "sparrow.json file validated ... \n";
 
-    execute_shell_command('tar --exclude=local --exclude=*.log  --exclude=log  --exclude-vcs -zcf /tmp/archive.tar.gz .' );
+    execute_shell_command('tar --exclude *.ini --exclude=local --exclude=*.log  --exclude=log  --exclude-vcs -zcf /tmp/archive.tar.gz .' );
     execute_shell_command(
         "curl -H 'sparrow-user: $cred->{user}' " .
         "-H 'sparrow-token: $cred->{token}' " .
@@ -341,6 +343,19 @@ sub upload_plugin {
 
 }
 
+sub plugin_meta {
+
+    my $path = shift or confess('usage: plugin_mate(path)');
+
+    open F, "$path/sparrow.json" or confess "can't open sparrow.json to read: $!";
+    my $s = join "", <F>;
+    close F;
+
+    my $spj = decode_json($s);
+
+    return $spj;
+
+}
 
 1;
 
